﻿using System;
using System.Collections.Generic;
using Rhino;
using Rhino.Commands;
using Rhino.Geometry;
using Rhino.Input;
using Rhino.Input.Custom;
using Mit.Umi.RhinoServices.Context;
using Mit.Umi.Core;

namespace TransitCarbonDemo
{
    [System.Runtime.InteropServices.Guid("528b12ba-d308-4a04-894a-3b9c6abcb663")]
    public class CalculateTransitCarbon : Command
    {
        public CalculateTransitCarbon()
        {
            // Rhino only creates one instance of each command class defined in a
            // plug-in, so it is safe to store a refence in a static property.
            Instance = this;
        }

        ///<summary>The only instance of this command.</summary>
        public static CalculateTransitCarbon Instance
        {
            get; private set;
        }

        ///<returns>The command name as it appears on the Rhino command line.</returns>
        public override string EnglishName
        {
            get { return "CalculateTransitCarbon"; }
        }

        protected override Result RunCommand(RhinoDoc doc, RunMode mode)
        {
            var context = UmiContext.Current;

            if (context == null)
            {
                RhinoApp.WriteLine("No UMI project is loaded!");
                return Result.Failure;
            }

            var databaseObjects = new List<IUmiObject>();

            foreach (var building in context.Buildings.Visible)
            {
                var occupancy = building.Occupancy;

                if (occupancy.HasValue)
                {
                    var carbon = occupancy.Value * TransitCarbonDemoPlugIn.Instance.TransitCarbonSettings.TransitCarbonFactor;

                    RhinoApp.WriteLine("{0}: {1} kgCO2/year", building.Name, carbon);

                    TransitCarbonDemoPlugIn.Instance.Results[building.Id] = carbon;

                    var series = new UmiDataSeries()
                    {
                        Name = "Transit Carbon",
                        Units = "kgCO2/year",
                        Data = new[] { carbon }
                    };

                    var databaseObject = UmiObject.Create(building.Name, building.Id.ToString(), series);

                    databaseObjects.Add(databaseObject);
                }
            }

            context.StoreObjects(databaseObjects);

            return Result.Success;
        }
    }
}
